# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).


## [Unreleased](https://github.com/tomdyson/wagtail-netlify/compare/v0.1...HEAD)

## [v0.1](https://github.com/tomdyson/wagtail-netlify/compare/f8f45701f43e28e238fc64aceea07dd1900343fc...v0.1)

Initial Release
